@@ -1,7 +1,16 @@
 import numpy as np
-from cv2 import (ADAPTIVE_THRESH_MEAN_C, BORDER_REPLICATE, COLOR_RGB2GRAY,
-                 INTER_AREA, INTER_CUBIC, THRESH_BINARY, adaptiveThreshold,
-                 cvtColor, remap, resize)
+from cv2 import (
+    ADAPTIVE_THRESH_MEAN_C,
+    BORDER_REPLICATE,
+    COLOR_RGB2GRAY,
+    INTER_AREA,
+    INTER_CUBIC,
+    THRESH_BINARY,
+    adaptiveThreshold,
+    cvtColor,
+    remap,
+    resize,
+)
 from PIL import Image
 
 from .debug_utils import debug_show
