@@ -1,6 +1,13 @@
 import numpy as np
-from cv2 import (ADAPTIVE_THRESH_MEAN_C, COLOR_RGB2GRAY, THRESH_BINARY_INV,
-                 adaptiveThreshold, cvtColor, dilate, erode)
+from cv2 import (
+    ADAPTIVE_THRESH_MEAN_C,
+    COLOR_RGB2GRAY,
+    THRESH_BINARY_INV,
+    adaptiveThreshold,
+    cvtColor,
+    dilate,
+    erode,
+)
 
 from .contours import get_contours
 from .debug_utils import debug_show
